Class: Skyfall::Jetstream::Operation

Inherits:
Object
  • Object
show all
Defined in:
lib/skyfall/jetstream/operation.rb

Overview

A single record operation from a Jetstream commit event. An operation is a new record being created, or an existing record modified or deleted. It includes the URI and other details of the record in question, type of the action taken, and record data for “created” and “update” actions.

Note: when a record is deleted, the previous record data is not included in the commit, only its URI. This means that if you’re tracking records which are referencing other records, e.g. follow, block, or like records, you need to store information about this referencing record including an URI or rkey, because in case of a delete, you will not get information about which post was unliked or which account was unfollowed, only which like/follow record was deleted.

At the moment, Skyfall doesn’t parse the record data into any rich models specific for a given record type with a convenient API, but simply returns them as Hash objects (see #raw_record). In the future, a second #record method might be added which returns a parsed record model.

Instance Method Summary collapse

Constructor Details

#initialize(message, json) ⇒ Operation

Returns a new instance of Operation.

Parameters:



31
32
33
34
# File 'lib/skyfall/jetstream/operation.rb', line 31

def initialize(message, json)
  @message = message
  @json = json
end

Instance Method Details

#actionSymbol

Returns type of the operation (:create, :update or :delete).

Returns:

  • (Symbol)

    type of the operation (:create, :update or :delete)



57
58
59
# File 'lib/skyfall/jetstream/operation.rb', line 57

def action
  @json['operation'].to_sym
end

#cidCID?

Returns CID (Content Identifier) of the record (nil for delete operations).

Returns:

  • (CID, nil)

    CID (Content Identifier) of the record (nil for delete operations)



77
78
79
# File 'lib/skyfall/jetstream/operation.rb', line 77

def cid
  @cid ||= @json['cid'] && CID.from_json(@json['cid'])
end

#collectionString

Returns record collection NSID.

Returns:

  • (String)

    record collection NSID



62
63
64
# File 'lib/skyfall/jetstream/operation.rb', line 62

def collection
  @json['collection']
end

#inspectString

Returns a string with a representation of the object for debugging purposes.

Returns:

  • (String)


99
100
101
102
# File 'lib/skyfall/jetstream/operation.rb', line 99

def inspect
  vars = inspectable_variables.map { |v| "#{v}=#{instance_variable_get(v).inspect}" }.join(", ")
  "#<#{self.class}:0x#{object_id} #{vars}>"
end

#pathString

Deprecated.

Returns path part of the record URI (collection + rkey).

Returns:

  • (String)

    path part of the record URI (collection + rkey)



45
46
47
48
49
50
51
52
53
54
# File 'lib/skyfall/jetstream/operation.rb', line 45

def path
  @@path_warning_printed ||= false

  unless @@path_warning_printed
    $stderr.puts "Warning: Skyfall::Jetstream::Operation#path is deprecated - use #collection + #rkey"
    @@path_warning_printed = true
  end

  @json['collection'] + '/' + @json['rkey']
end

#raw_recordHash?

Returns record data as a plain Ruby Hash (nil for delete operations).

Returns:

  • (Hash, nil)

    record data as a plain Ruby Hash (nil for delete operations)



82
83
84
# File 'lib/skyfall/jetstream/operation.rb', line 82

def raw_record
  @json['record']
end

#repoString Also known as: did

Returns DID of the account/repository in which the operation happened.

Returns:

  • (String)

    DID of the account/repository in which the operation happened



37
38
39
# File 'lib/skyfall/jetstream/operation.rb', line 37

def repo
  @message.repo
end

#rkeyString

Returns record rkey.

Returns:

  • (String)

    record rkey



67
68
69
# File 'lib/skyfall/jetstream/operation.rb', line 67

def rkey
  @json['rkey']
end

#typeSymbol

Symbol short code of the collection, like :bsky_post. If the collection NSID is not recognized, the type is :unknown. The full NSID is always available through the #collection property.

Returns:

  • (Symbol)

See Also:



93
94
95
# File 'lib/skyfall/jetstream/operation.rb', line 93

def type
  Collection.short_code(collection)
end

#uriString

Returns full AT URI of the record.

Returns:

  • (String)

    full AT URI of the record



72
73
74
# File 'lib/skyfall/jetstream/operation.rb', line 72

def uri
  "at://#{repo}/#{collection}/#{rkey}"
end