Exception: Skyfall::UnsupportedError

Inherits:
Error
  • Object
show all
Defined in:
lib/skyfall/errors.rb

Overview

Raised when the server sends a message which is formatted correctly, but written in a version that’s not supported by this library.